IrListSchema class

An array/list schema.

Inheritance

Constructors

IrListSchema({required IrSchema items, bool isNullable = false, String? description, bool isDeprecated = false})

Properties

description String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isDeprecated bool
getter/setter pairinherited
isNullable bool
final
items IrSchema
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited