IrSecurityScheme class

A security scheme definition.

Constructors

IrSecurityScheme({required String name, required String type, String? scheme, String? bearerFormat, String? description})

Properties

bearerFormat String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited